.. image:: https://travis-ci.org/1st1/greenio.svg?branch=master
    :target: https://travis-ci.org/1st1/greenio


Support for greenlets in asyncio.

Requires asyncio, greenlet and Python 3.3 / 3.4.

See examples and unittests for details.
To run tests: "$ python3 runtests.py"

License: Apache 2.0
